]> git.cworth.org Git - fips/blobdiff - execute.h
Allow fips to compile with OpenGL without GLfixed
[fips] / execute.h
index 8b9192f7ca5bfbe41e19221d324ad6fd1da6d411..c1ba3bca1d35932ba26547a0ad321621da7cbecb 100644 (file)
--- a/execute.h
+++ b/execute.h
 #ifndef EXECUTE_H
 #define EXECUTE_H
 
/* Execute the program with arguments as specified.
  */
 int
-execute (int argc, char * const argv[]);
+execute_with_fips_preload (int argc, char * const argv[]);
 
 #endif
@@
 #define EXECUTE_H
 
-/* Execute the program with arguments as specified.
+/* Execute the program with arguments as specified, but with the
+ * fips library specified as an LD_PRELOAD.
  */
 int